@@ -8,6 +8,7 @@ from titiler.application.custom import templates
 from titiler.application.middleware import (
     CacheControlMiddleware,
     LoggerMiddleware,
+    LowerCaseQueryStringMiddleware,
     TotalTimeMiddleware,
 )
 from titiler.application.routers import cog, mosaic, stac, tms
@@ -32,6 +33,7 @@ app = FastAPI(
     title=api_settings.name,
     description="A lightweight Cloud Optimized GeoTIFF tile server",
     version=titiler_version,
+    root_path=api_settings.root_path,
 )
 
 if not api_settings.disable_cog:
@@ -71,6 +73,9 @@ if api_settings.debug:
     app.add_middleware(LoggerMiddleware, headers=True, querystrings=True)
     app.add_middleware(TotalTimeMiddleware)
 
+if api_settings.lower_case_query_parameters:
+    app.add_middleware(LowerCaseQueryStringMiddleware)
+
 
 @app.get("/healthz", description="Health Check", tags=["Health Check"])
 def ping():
